=== modified file 'bzrlib/bugtracker.py'
--- bzrlib/bugtracker.py	2009-03-12 08:17:41 +0000
+++ bzrlib/bugtracker.py	2009-03-19 03:58:36 +0000
@@ -14,8 +14,6 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-import textwrap
-
 from bzrlib import registry, help_topics
 from bzrlib.lazy_import import lazy_import
 lazy_import(globals(), """

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2009-03-18 15:38:56 +0000
+++ bzrlib/bzrdir.py	2009-03-19 03:58:36 +0000
@@ -2999,8 +2999,10 @@
             if info.native:
                 help = '(native) ' + help
             return ':%s:\n%s\n\n' % (key,
-                    textwrap.fill(help, initial_indent='    ',
-                    subsequent_indent='    '))
+                textwrap.fill(help, initial_indent='    ',
+                    subsequent_indent='    ',
+                    break_long_words=False,
+                    break_on_hyphens=False))
         if default_realkey is not None:
             output += wrapped(default_realkey, '(default) %s' % default_help,
                               self.get_info('default'))

=== modified file 'bzrlib/help.py'
--- bzrlib/help.py	2009-02-26 06:15:24 +0000
+++ bzrlib/help.py	2009-03-19 03:58:36 +0000
@@ -94,8 +94,11 @@
         else:
             firstline = ''
         helpstring = '%-*s %s%s' % (max_name, cmd_name, firstline, plugin_name)
-        lines = textwrap.wrap(helpstring, subsequent_indent=indent,
-                              width=width)
+        lines = textwrap.wrap(
+            helpstring, subsequent_indent=indent,
+            width=width,
+            break_long_words=False,
+            break_on_hyphens=False)
         for line in lines:
             out.append(line + '\n')
     return ''.join(out)

=== modified file 'bzrlib/help_topics/__init__.py'
--- bzrlib/help_topics/__init__.py	2009-03-13 03:01:14 +0000
+++ bzrlib/help_topics/__init__.py	2009-03-19 03:58:36 +0000
@@ -207,7 +207,9 @@
     import textwrap
 
     def add_string(proto, help, maxl, prefix_width=20):
-       help_lines = textwrap.wrap(help, maxl - prefix_width)
+       help_lines = textwrap.wrap(help, maxl - prefix_width,
+            break_long_words=False,
+            break_on_hyphens=False)
        line_with_indent = '\n' + ' ' * prefix_width
        help_text = line_with_indent.join(help_lines)
        return "%-20s%s\n" % (proto, help_text)

=== modified file 'bzrlib/hooks.py'
--- bzrlib/hooks.py	2009-03-18 03:47:30 +0000
+++ bzrlib/hooks.py	2009-03-19 03:58:36 +0000
@@ -221,7 +221,9 @@
             deprecated_string = 'Not deprecated'
         strings.append('Deprecated in: %s' % deprecated_string)
         strings.append('')
-        strings.extend(textwrap.wrap(self.__doc__))
+        strings.extend(textwrap.wrap(self.__doc__,
+            break_long_words=False,
+            break_on_hyphens=False))
         strings.append('')
         return '\n'.join(strings)
 

=== modified file 'tools/doc_generate/autodoc_man.py'
--- tools/doc_generate/autodoc_man.py	2009-03-10 06:36:27 +0000
+++ tools/doc_generate/autodoc_man.py	2009-03-19 03:58:36 +0000
@@ -127,7 +127,9 @@
                     l += ', -' + short_name
                 l += (30 - len(l)) * ' ' + (help or '')
                 wrapped = textwrap.fill(l, initial_indent='',
-                                        subsequent_indent=30*' ')
+                    subsequent_indent=30*' ',
+                    break_long_words=False,
+                    break_on_hyphens=False)
                 option_str = option_str + wrapped + '\n'       
 
     aliases_str = ""

=== modified file 'tools/doc_generate/autodoc_rstx.py'
--- tools/doc_generate/autodoc_rstx.py	2008-07-19 15:00:27 +0000
+++ tools/doc_generate/autodoc_rstx.py	2009-03-19 03:58:36 +0000
@@ -22,7 +22,6 @@
 
 import os
 import sys
-import textwrap
 import time
 
 import bzrlib

